# smarter-kettle-client
Python client for Smarter Kettle integration

[![CI](https://github.com/kbirger/smarter-kettle-client/actions/workflows/ci.yml/badge.svg)](https://github.com/kbirger/smarter-kettle-client/actions/workflows/ci.yml)
[![Coverage](https://coverage-badge.samuelcolvin.workers.dev/kbirger/smarter-kettle-client.svg)](https://coverage-badge.samuelcolvin.workers.dev/redirect/kbirger/smarter-kettle-client)
[![pypi](https://img.shields.io/pypi/v/smarter-client.svg)](https://pypi.python.org/pypi/smarter-client)
[![downloads](https://static.pepy.tech/badge/smarter-client/month)](https://pepy.tech/project/smarter-client)
[![versions](https://img.shields.io/pypi/pyversions/smarter-client.svg)](https://github.com/smarter-kettle-client/smarter-client)
[![license](https://img.shields.io/github/license/kbirger/smarter-kettle-client.svg)](https://github.com/kbirger/smarter-kettle-client/smarter-kettle-client/blob/main/LICENSE)
[![smarter-kettle-client](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/kbirger/smarter-kettle-client/main/docs/badge/v2.json)](https://docs.smarter-kettle-client.dev/latest/contributing/#badges)

